import os
from dockdj.du_settings import CONFIG_FILE
from fabric import Connection
import yaml
from invoke import exceptions


def logs(verbose=False):
    if not os.path.isfile(CONFIG_FILE):
        print("Please run django_up init to create config file")
        return

    with open(CONFIG_FILE, 'r') as the_file:
        config_yaml = yaml.load(the_file)

    app_name = config_yaml['app']['name']

    for server in config_yaml['servers']:
        with Connection(
                host=server['host'],
                user=server['username'],
                connect_kwargs={'key_filename': server['pem']}) as cnx:
            try:
                cnx.run(f'docker logs {app_name}')
            except exceptions.UnexpectedExit:
                print('Some thing went wrong')



from typing import Dict
import os
from dockdj.du_settings import CONFIG_FILE, SETTINGS_PY_FILE
import yaml
from sys import exit


def read_config_files() -> (Dict, str):
    if not os.path.isfile(CONFIG_FILE):
        print(f'Please run "dockdj" init to create {CONFIG_FILE} file')
        exit()

    if not os.path.isfile(SETTINGS_PY_FILE):
        print(f'Please run "dockdj init" to create {SETTINGS_PY_FILE} file')
        exit()

    with open(CONFIG_FILE, 'r') as the_file:
        config_yaml = yaml.load(the_file)

    with open(SETTINGS_PY_FILE, 'r') as the_file:
        settings_py = the_file.read()

    return config_yaml, settings_py



import os.path
from dockdj.du_settings import CONFIG_FILE, SETTINGS_PY_FILE


INIT_YAML = '''---
servers:
- host: 1.2.3.4
  # must be sudo without password
  username: root
  pem: "/home/user/.ssh/id_rsa"
  # optional
  env:
    PER_SERVER: abc
app:
  # Any name used by script to name docker
  name: abc
  # Django app dir which contains wsgi.py and settings.py
  django_app: 'hello_world'
  requirements_file: 'requirements.txt'
  port: 80
  # Django app dir which contains wsgi.py and settings.py
  path: "/path/to/project"
  docker:
    image: python:3.7
  env:
    FOO: foo
    BAR: bar
'''


SETTING_PY = '''
DEBUG = False

# Add the your servers host name or ip address
ALLOWED_HOSTS = []
'''


def init(verbose=False):

    if os.path.isfile(CONFIG_FILE):
        print(f'File {CONFIG_FILE} already exists.')
        return

    if os.path.isfile(SETTINGS_PY_FILE):
        print(f'File {SETTINGS_PY_FILE} already exists.')
        return

    with open(CONFIG_FILE, 'w') as the_file:
        the_file.write(INIT_YAML)

    with open(SETTINGS_PY_FILE, 'w') as the_file:
        the_file.write(SETTING_PY)



import os
from dockdj.du_settings import CONFIG_FILE
from fabric import Connection
import yaml
from invoke import exceptions


def setup(verbose=False):
    hide = not verbose
    if not os.path.isfile(CONFIG_FILE):
        print("Please run django_up init to create config file")
        return

    with open(CONFIG_FILE, 'r') as the_file:
        config_yaml = yaml.load(the_file)

    for server in config_yaml['servers']:
        with Connection(
                host=server['host'],
                user=server['username'],
                connect_kwargs={'key_filename': server['pem']}) as cnx:
            try:
                cnx.run('docker -v', hide=hide)
                print('Docker already present')
            except exceptions.UnexpectedExit:
                print('Docker not present')
                install_docker(cnx, hide=hide)


def install_docker(cnx, hide=True):
    print('Installing docker')
    cnx.run('sudo apt-get update', hide=hide)
    cnx.run('sudo apt-get install unzip apt-transport-https ca-certificates curl software-properties-common -y',
            hide=hide)
    cnx.run('curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo apt-key add -', hide=hide)
    cnx.run('add-apt-repository "deb [arch=amd64] https://download.docker.com/linux/ubuntu $(lsb_release -cs) stable"',
            hide=hide)
    cnx.run('sudo apt-get update', hide=hide)
    cnx.run('sudo apt-get install docker-ce -y', hide=hide)
    print('Completed')
